@@ -34,15 +34,32 @@ class AsyncFetcher:
         show_progress_bar: bool = True,
         timeout_s: float = 5.0,
         client=None,
+        close_client: bool = False,
         **kwargs,
     ):
         """
         Any kwargs are passed through to the stream class constructor.
 
         Args:
-          callback : A function to be passed 3 values: the AsyncFetcher which is calling
-                     it, the awaited RangeStream, and its source URL (a ``httpx.URL``,
-                     which can be coerced to a string).
+          stream_cls        : The :class:`~range_streams.stream.RangeStream` class or a
+                              subclass (i.e. one of its codecs or a custom subclass)
+                              to instantiate for each of the URLs. Note: these classes
+                              also have a helper method
+                              :meth:`~range_streams.stream.RangeStream.make_async_fetcher`
+          urls              : The list of URLs to fetch until completion
+          callback          : A function to be passed 3 values: the AsyncFetcher which
+                              is calling it, the awaited RangeStream, and its source URL
+                              (a ``httpx.URL``, which can be coerced to a string).
+          verbose           : Whether to log to console
+          show_progress_bar : Whether to show a tqdm progress bar (async-compatible)
+          timeout_s         : The timeout to set on the client (converted into
+                              ``httpx.Timeout`` configuration on instantiation)
+          client            : The client to pass, if any, or one will be instantiated
+                              and closed on each usage (note: not each instantiation!)
+          close_client      : Whether to close the client upon completion (only if
+                              provided: if no client is provided, one will be created
+                              and closed by the standard `async with httpx.AsyncClient`
+                              contextmanager block).
         """
         if urls == []:
             raise ValueError("The list of URLs to fetch cannot be empty")
@@ -59,6 +76,7 @@ class AsyncFetcher:
         self.verbose = verbose
         self.show_progress_bar = show_progress_bar and not self.verbose
         self.client = client
+        self.close_client_on_completion = close_client
         self.timeout = httpx.Timeout(timeout=timeout_s)
         self.completed = RangeSet()
         set_up_logging(quiet=not verbose)
@@ -78,7 +96,7 @@ class AsyncFetcher:
     async def process_stream(self, range_stream: RangeStreamOrSubclass):
         """
         Process an awaited RangeStream within an async fetch loop, calling the callback
-        set on the `~range_streams.async_utils.AsyncFetcher.callback` attribute.
+        set on the :attr:`~range_streams.async_utils.AsyncFetcher.callback` attribute.
 
         Args:
           range_stream : The awaited RangeStream (or one of its subclasses)
@@ -174,6 +192,9 @@ class AsyncFetcher:
         in a contextmanager block (i.e. close it immediately after use), otherwise use
         the one provided, not in a contextmanager block (i.e. leave it up to the user to
         close the client).
+
+        Args:
+          urls         : The URLs to fetch, as an exhaustible iterator (not a Sequence)
         """
         await self.set_async_signal_handlers()
         if self.client is None:
@@ -189,6 +210,8 @@ class AsyncFetcher:
                 raise ValueError(msg)
             # assert self.client is not None # give mypy a clue
             processed = await self.fetch_and_process(urls=urls, client=self.client)
+            if self.close_client_on_completion:
+                await self.client.aclose()
         return processed
 
     async def fetch_and_process(self, urls: Iterator[str], client):
